/**
  \file Firmware-0.3.0.ino
  Copyright (C) 2018 Xoán Sampaíño

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#include <EscornabotEXT.h>
#include <EXTpad.h>

const int GRID_SIZE = 100;
const int GRID_ANGLE = 90;

enum Move : byte {
  MOVE_NONE = 0,
  MOVE_FORWARD = 1,
  MOVE_BACK = 2,
  MOVE_LEFT = 3,
  MOVE_RIGHT = 4
};

EscornabotEXT kanoi;

/**
  \param none_value
  \param forward_value
  \param back_value
  \param left_value
  \param right_value
  \param go_value
*/
EXTpad keypad(0, 672, 335, 501, 168, 846);

void setup() {
  kanoi.begin();
  keypad.begin();
  
  kanoi.beep(100);
}

void loop() {
  switch (keypad.scan()) {
    case BUTTON_FORWARD:
      kanoi.beep(100);
      
      record(MOVE_FORWARD);
      break;
      
    case BUTTON_BACK:
      kanoi.beep(100);
      
      record(MOVE_BACK);
      break;
      
    case BUTTON_LEFT:
      kanoi.beep(100);
      
      record(MOVE_LEFT);
      break;
      
    case BUTTON_RIGHT:
      kanoi.beep(100);
      
      record(MOVE_RIGHT);
      break;
      
    case BUTTON_GO:
      kanoi.beep(100);
      kanoi.wait(200);
      
      play();
      
      kanoi.beep(100);
      break;
  }
  
  delay(10);
}

byte move_list[128];
byte move_count = 0;

void record(byte move) {
  if (move_count < sizeof(move_list)) {
    move_list[move_count++] = move;
  } else {
    play();
  }
}

void play() {
  if (move_count > 0) {
    for (byte i = 0; i < move_count; i++) {
      switch (move_list[i]) {
        case MOVE_FORWARD:
          kanoi.forward(GRID_SIZE);
          kanoi.beep(50);
          break;
          
        case MOVE_BACK:
          kanoi.back(GRID_SIZE);
          kanoi.beep(50);
          break;
          
        case MOVE_LEFT:
          kanoi.left(GRID_ANGLE);
          kanoi.beep(50);
          break;
          
        case MOVE_RIGHT:
          kanoi.right(GRID_ANGLE);
          kanoi.beep(50);
          break;
      }
    }
    
    move_count = 0;
  }
}

// EOF
