/**
  \file EXTpad.cpp
  Copyright (C) 2018 Xoán Sampaíño
  Based on Escornabot <https://github.com/escornabot>

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#include "EXTpad.h"

EXTpad::EXTpad(int none_value, int forward_value, int back_value,
               int left_value, int right_value, int go_value) {
  _value[0] = none_value;
  _value[1] = forward_value;
  _value[2] = back_value;
  _value[3] = left_value;
  _value[4] = right_value;
  _value[5] = go_value;
}

void EXTpad::begin() {
  pinMode(BUTTON_PIN, INPUT);
}

byte EXTpad::scan() {
  int value = analogRead(BUTTON_PIN);
  int diff, minor_diff;

  minor_diff = value;
  byte button = BUTTON_NONE;

  diff = abs(value - _value[1]);
  
  if (diff < minor_diff) {
    minor_diff = diff;
    button = BUTTON_FORWARD;
  }

  diff = abs(value - _value[2]);
  
  if (diff < minor_diff) {
    minor_diff = diff;
    button = BUTTON_BACK;
  }

  diff = abs(value - _value[3]);
  
  if (diff < minor_diff) {
    minor_diff = diff;
    button = BUTTON_LEFT;
  }

  diff = abs(value - _value[4]);
  
  if (diff < minor_diff) {
    minor_diff = diff;
    button = BUTTON_RIGHT;
  }

  diff = abs(value - _value[5]);
  
  if (diff < minor_diff) {
    minor_diff = diff;
    button = BUTTON_GO;
  }
  
  if (millis() - _millis > BUTTON_PRESSED) {
    _millis = millis();
    
    if (button != _last_button) {
      _last_button = button;
      return button;
    }
  }

  return BUTTON_NONE;
}

// EOF
