/**
  \file EXTpad.h 
  Copyright (C) 2018 Xoán Sampaíño
  Based on Escornabot <https://github.com/escornabot>

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef _EXT_PAD_H
#define _EXT_PAD_H

#include <Arduino.h>

const int BUTTON_PRESSED = 50;

const byte BUTTON_PIN = A0;

enum Button : byte {
  BUTTON_NONE = 0,
  BUTTON_FORWARD = 1,
  BUTTON_BACK = 2,
  BUTTON_LEFT = 3,
  BUTTON_RIGHT = 4,
  BUTTON_GO = 5
};

class EXTpad {
  /**
    \class EXTpad EXTpad.h <EXTpad.h>
  */
  public:
    /**
      Constructor
      
      \param none_value Analog value when BUTTON_NONE is pressed
      \param forward_value Analog value when BUTTON_FORWARD is pressed
      \param back_value Analog value when BUTTON_BACK is pressed
      \param left_value Analog value when BUTTON_LEFT is pressed
      \param right_value Analog value when BUTTON_RIGHT is pressed
      \param go_value Analog value when BUTTON_GO is pressed
    */
    EXTpad(int none_value = 0, int forward_value = 672, int back_value = 335,
           int left_value = 501, int right_value = 168, int go_value = 846);
    
    /**
    */
    void begin();
    
    /**
    */
    byte scan();
    
  private:
    int _value[6];
    byte _last_button = BUTTON_NONE;
    unsigned long _millis = 0;
};

#endif // _EXT_PAD_H

// EOF
